@@ -2,7 +2,6 @@ package org.gcube.portlets.user.wsmail.client.multisuggests;
 
 import java.util.ArrayList;
 
-import org.gcube.portlets.user.workspace.lighttree.client.Item;
 import org.gcube.portlets.user.wsmail.client.WsMailService;
 import org.gcube.portlets.user.wsmail.client.WsMailServiceAsync;
 import org.gcube.portlets.user.wsmail.client.events.RenderForm;
@@ -202,12 +201,14 @@ public class MultiValuePanel extends Composite {
 
 			@Override
 			public void onSuccess(CurrUserAndPortalUsersWrapper result) {
+				GWT.log("oh");
 				currentUser = result.getCurrentUser(); 
 				for (WSUser wsUser : result.getUsers()) {
 					GWT.log(wsUser.getFullName());
 					oracle.add(wsUser.getFullName());
 				}				
 				users = result.getUsers();
+				GWT.log("doh");
 				eventBus.fireEvent(new RenderForm(true));
 			}
 
